@@ -16,7 +16,7 @@
         <translation>Błąd:%1</translation>
     </message>
     <message>
-        <location filename="../src/converter.cpp" line="290"/>
+        <location filename="../src/converter.cpp" line="299"/>
         <source>ERROR: Format %1 is not supported for writing, choose another output format. Skipping!</source>
         <translation type="unfinished"></translation>
     </message>
@@ -599,12 +599,12 @@ p, li { white-space: pre-wrap; }
 <context>
     <name>Formats</name>
     <message>
-        <location filename="../src/formats.cpp" line="105"/>
+        <location filename="../src/formats.cpp" line="110"/>
         <source>All Supported Filters (%1)</source>
         <translation>Wszystkie wspierane filtry (%1)</translation>
     </message>
     <message>
-        <location filename="../src/formats.cpp" line="112"/>
+        <location filename="../src/formats.cpp" line="119"/>
         <source>Don&apos;t change the format</source>
         <translation>Nie zmieniaj formatu</translation>
     </message>
@@ -1181,140 +1181,161 @@ p, li { white-space: pre-wrap; }
 <context>
     <name>MainWindowImpl</name>
     <message>
-        <location filename="../src/mainwindowimpl.cpp" line="257"/>
+        <location filename="../src/mainwindowimpl.cpp" line="252"/>
         <source>Open Image</source>
         <translation>Otwórz obraz</translation>
     </message>
     <message>
-        <location filename="../src/mainwindowimpl.cpp" line="278"/>
+        <location filename="../src/mainwindowimpl.cpp" line="273"/>
         <source>Do you want to import subfolders as well?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindowimpl.cpp" line="307"/>
+        <location filename="../src/mainwindowimpl.cpp" line="302"/>
         <source>Open Icon file</source>
         <translation>Otwórz plik Icon</translation>
     </message>
     <message>
-        <location filename="../src/mainwindowimpl.cpp" line="307"/>
+        <location filename="../src/mainwindowimpl.cpp" line="302"/>
         <source>Microsoft icon (*.ico *.icon)</source>
         <translation>Ikona Microsoft Windows (*ico *.icon)</translation>
     </message>
     <message>
-        <location filename="../src/mainwindowimpl.cpp" line="318"/>
+        <location filename="../src/mainwindowimpl.cpp" line="313"/>
         <source>Open Pdf file</source>
         <translation>Otwórz plik PDF</translation>
     </message>
     <message>
-        <location filename="../src/mainwindowimpl.cpp" line="318"/>
+        <location filename="../src/mainwindowimpl.cpp" line="313"/>
         <source>Portable Document Format (*.pdf)</source>
         <translation>Portable Document Format (*.pdf)</translation>
     </message>
     <message>
-        <location filename="../src/mainwindowimpl.cpp" line="328"/>
+        <location filename="../src/mainwindowimpl.cpp" line="323"/>
         <source>Analyzing the file. It may take a while, please wait...</source>
         <translation>Trwa analiza pliku. Może to chwilę zająć, proszę czekać...</translation>
     </message>
     <message>
-        <location filename="../src/mainwindowimpl.cpp" line="352"/>
+        <location filename="../src/mainwindowimpl.cpp" line="347"/>
         <source>You are going to import %1 directories. Do you want to import subfolders as well?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindowimpl.cpp" line="417"/>
+        <location filename="../src/mainwindowimpl.cpp" line="452"/>
         <source>n/a</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindowimpl.cpp" line="457"/>
-        <location filename="../src/mainwindowimpl.cpp" line="463"/>
-        <location filename="../src/mainwindowimpl.cpp" line="472"/>
-        <location filename="../src/mainwindowimpl.cpp" line="476"/>
-        <location filename="../src/mainwindowimpl.cpp" line="480"/>
+        <location filename="../src/mainwindowimpl.cpp" line="492"/>
+        <location filename="../src/mainwindowimpl.cpp" line="498"/>
+        <location filename="../src/mainwindowimpl.cpp" line="507"/>
+        <location filename="../src/mainwindowimpl.cpp" line="511"/>
+        <location filename="../src/mainwindowimpl.cpp" line="515"/>
         <source>Warning</source>
         <translation>Ostrzeżenie</translation>
     </message>
     <message>
-        <location filename="../src/mainwindowimpl.cpp" line="458"/>
+        <location filename="../src/mainwindowimpl.cpp" line="493"/>
         <source>The output directory doesn&apos;t exists! Would you create it?</source>
         <translation>Brak katalogu docelowego! Utworzyć?</translation>
     </message>
     <message>
-        <location filename="../src/mainwindowimpl.cpp" line="464"/>
+        <location filename="../src/mainwindowimpl.cpp" line="499"/>
         <source>The directory cannot be created!</source>
         <translation>Nie można utworzyć katalogu!</translation>
     </message>
     <message>
-        <location filename="../src/mainwindowimpl.cpp" line="473"/>
+        <location filename="../src/mainwindowimpl.cpp" line="508"/>
         <source>Set an output directory!</source>
         <translation>Wybierz katalog docelowy!</translation>
     </message>
     <message>
-        <location filename="../src/mainwindowimpl.cpp" line="477"/>
+        <location filename="../src/mainwindowimpl.cpp" line="512"/>
         <source>No image checked!</source>
         <translation>Nie sprawdzono!</translation>
     </message>
     <message>
-        <location filename="../src/mainwindowimpl.cpp" line="481"/>
+        <location filename="../src/mainwindowimpl.cpp" line="516"/>
         <source>No images to convert!</source>
         <translation>Brak obrazków do konwersji!</translation>
     </message>
     <message>
-        <location filename="../src/mainwindowimpl.cpp" line="498"/>
+        <location filename="../src/mainwindowimpl.cpp" line="533"/>
         <source>Processing...</source>
         <translation>Przetwarzanie...</translation>
     </message>
     <message>
-        <location filename="../src/mainwindowimpl.cpp" line="671"/>
+        <location filename="../src/mainwindowimpl.cpp" line="706"/>
         <source>Converted</source>
         <translation type="unfinished">Skonwertowany</translation>
     </message>
     <message>
-        <location filename="../src/mainwindowimpl.cpp" line="676"/>
+        <location filename="../src/mainwindowimpl.cpp" line="711"/>
         <source>Skipped</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindowimpl.cpp" line="678"/>
+        <location filename="../src/mainwindowimpl.cpp" line="713"/>
         <source>Error</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindowimpl.cpp" line="687"/>
+        <location filename="../src/mainwindowimpl.cpp" line="722"/>
         <source>Processing finished!</source>
         <translation>Ukończono przetwarzanie!</translation>
     </message>
     <message>
-        <location filename="../src/mainwindowimpl.cpp" line="271"/>
-        <location filename="../src/mainwindowimpl.cpp" line="741"/>
+        <location filename="../src/mainwindowimpl.cpp" line="1316"/>
+        <source>No updates available!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindowimpl.cpp" line="1317"/>
+        <source>%1 is already updated to the most recent version.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindowimpl.cpp" line="1334"/>
+        <source>New version is available!</source>
+        <translation type="unfinished">Dostępna jest nowa wersja!</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindowimpl.cpp" line="1335"/>
+        <source>A new version of %1 is available!
+Would you download it?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindowimpl.cpp" line="266"/>
+        <location filename="../src/mainwindowimpl.cpp" line="776"/>
         <source>Open Directory</source>
         <translation>Otwórz katalog</translation>
     </message>
     <message>
-        <location filename="../src/mainwindowimpl.cpp" line="860"/>
-        <location filename="../src/mainwindowimpl.cpp" line="878"/>
-        <location filename="../src/mainwindowimpl.cpp" line="1051"/>
-        <location filename="../src/mainwindowimpl.cpp" line="1108"/>
+        <location filename="../src/mainwindowimpl.cpp" line="895"/>
+        <location filename="../src/mainwindowimpl.cpp" line="913"/>
+        <location filename="../src/mainwindowimpl.cpp" line="1086"/>
+        <location filename="../src/mainwindowimpl.cpp" line="1143"/>
         <source>Preview</source>
         <translation>Podgląd</translation>
     </message>
     <message>
-        <location filename="../src/mainwindowimpl.cpp" line="1186"/>
+        <location filename="../src/mainwindowimpl.cpp" line="1221"/>
         <source>Suggest a new name!</source>
         <translation>Podaj nową nazwę!</translation>
     </message>
     <message>
-        <location filename="../src/mainwindowimpl.cpp" line="1187"/>
+        <location filename="../src/mainwindowimpl.cpp" line="1222"/>
         <source>New name:</source>
         <translation>Nowa nazwa:</translation>
     </message>
     <message>
-        <location filename="../src/mainwindowimpl.cpp" line="1192"/>
+        <location filename="../src/mainwindowimpl.cpp" line="1227"/>
         <source>Please, specify a name!</source>
         <translation>Proszę utworzyć nazwę!</translation>
     </message>
     <message>
-        <location filename="../src/mainwindowimpl.cpp" line="1193"/>
+        <location filename="../src/mainwindowimpl.cpp" line="1228"/>
         <source>You should specify a name.
 Click Retry to specify a new name.
 Click Ignore to cancel this operation.
@@ -1325,23 +1346,23 @@ Kliknij Ignoruj, aby zakończyć tą operację.
 Kliknij Porzuć, aby zakończyć wszystkie operacje.</translation>
     </message>
     <message>
-        <location filename="../src/mainwindowimpl.cpp" line="1210"/>
-        <location filename="../src/mainwindowimpl.cpp" line="1215"/>
+        <location filename="../src/mainwindowimpl.cpp" line="1245"/>
+        <location filename="../src/mainwindowimpl.cpp" line="1250"/>
         <source>Warning!</source>
         <translation>Ostrzeżenie!</translation>
     </message>
     <message>
-        <location filename="../src/mainwindowimpl.cpp" line="1211"/>
+        <location filename="../src/mainwindowimpl.cpp" line="1246"/>
         <source>The filename should not be empty!</source>
         <translation>Nazwa pliku nie może być pusta!</translation>
     </message>
     <message>
-        <location filename="../src/mainwindowimpl.cpp" line="1216"/>
+        <location filename="../src/mainwindowimpl.cpp" line="1251"/>
         <source>The name chosen is identical to the initial one. Do you want to overwrite the original file?</source>
         <translation>Wybrano taką samą nazwę, jak istniejąca już. Nadpisać orgyinalny plik?</translation>
     </message>
     <message>
-        <location filename="../src/mainwindowimpl.cpp" line="1232"/>
+        <location filename="../src/mainwindowimpl.cpp" line="1267"/>
         <source>Aborted!</source>
         <translation>Przerwano!</translation>
     </message>
@@ -1398,20 +1419,6 @@ Kliknij Porzuć, aby zakończyć wszystkie operacje.</translation>
         <translation>Polski</translation>
     </message>
 </context>
-<context>
-    <name>UpdateChecker</name>
-    <message>
-        <location filename="../src/updatechecker.cpp" line="81"/>
-        <source>New version is available!</source>
-        <translation>Dostępna jest nowa wersja!</translation>
-    </message>
-    <message>
-        <location filename="../src/updatechecker.cpp" line="82"/>
-        <source>A new version of %1 is available!
-Would you download it?</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
 <context>
     <name>myLabelPreviewer</name>
     <message>
